@@ -81,11 +81,6 @@ if HAS_USER_SITE:
         'data'   : '{userbase}',
         }
 
-    INSTALL_SCHEMES['osx_framework_user'] = {
-        'headers':
-            '{userbase}/include/{implementation_lower}{py_version_short}{abiflags}/{dist_name}',
-    }
-
 # The keys to an installation scheme; if any new types of files are to be
 # installed, be sure to add an entry to every installation scheme above,
 # and to SCHEME_KEYS here.
@@ -123,6 +118,65 @@ def _get_implementation():
         return 'Python'
 
 
+def _select_scheme(ob, name):
+    scheme = _inject_headers(name, _load_scheme(_resolve_scheme(name)))
+    vars(ob).update(_remove_set(ob, _scheme_attrs(scheme)))
+
+
+def _remove_set(ob, attrs):
+    """
+    Include only attrs that are None in ob.
+    """
+    return {
+        key: value
+        for key, value in attrs.items()
+        if getattr(ob, key) is None
+    }
+
+
+def _resolve_scheme(name):
+    os_name, sep, key = name.partition('_')
+    try:
+        resolved = sysconfig.get_preferred_scheme(key)
+    except Exception:
+        resolved = _pypy_hack(name)
+    return resolved
+
+
+def _load_scheme(name):
+    return _load_schemes()[name]
+
+
+def _inject_headers(name, scheme):
+    """
+    Given a scheme name and the resolved scheme,
+    if the scheme does not include headers, resolve
+    the fallback scheme for the name and use headers
+    from it. pypa/distutils#88
+    """
+    # Bypass the preferred scheme, which may not
+    # have defined headers.
+    fallback = _load_scheme(_pypy_hack(name))
+    scheme.setdefault('headers', fallback['headers'])
+    return scheme
+
+
+def _scheme_attrs(scheme):
+    """Resolve install directories by applying the install schemes."""
+    return {
+        f'install_{key}': scheme[key]
+        for key in SCHEME_KEYS
+    }
+
+
+def _pypy_hack(name):
+    PY37 = sys.version_info < (3, 8)
+    old_pypy = hasattr(sys, 'pypy_version_info') and PY37
+    prefix = not name.endswith(('_user', '_home'))
+    pypy_name = 'pypy' + '_nt' * (os.name == 'nt')
+    return pypy_name if old_pypy and prefix else name
+
+
 class install(Command):
 
     description = "install everything from build directory"
@@ -354,6 +408,8 @@ class install(Command):
                             'platlibdir': getattr(sys, 'platlibdir', 'lib'),
                             'implementation_lower': _get_implementation().lower(),
                             'implementation': _get_implementation(),
+                            # all values must be str; see #86
+                            'platsubdir': str(sysconfig.get_config_var('platsubdir')),
                            }
 
         if HAS_USER_SITE:
@@ -520,29 +576,7 @@ class install(Command):
                       "I don't know how to install stuff on '%s'" % os.name)
 
     def select_scheme(self, name):
-        os_name, sep, key = name.partition('_')
-        try:
-            resolved = sysconfig.get_preferred_scheme(key)
-        except Exception:
-            resolved = self._pypy_hack(name)
-        return self._select_scheme(resolved)
-
-    def _select_scheme(self, name):
-        """Sets the install directories by applying the install schemes."""
-        # it's the caller's problem if they supply a bad name!
-        scheme = _load_schemes()[name]
-        for key in SCHEME_KEYS:
-            attrname = 'install_' + key
-            if getattr(self, attrname) is None:
-                setattr(self, attrname, scheme[key])
-
-    @staticmethod
-    def _pypy_hack(name):
-        PY37 = sys.version_info < (3, 8)
-        old_pypy = hasattr(sys, 'pypy_version_info') and PY37
-        prefix = not name.endswith(('_user', '_home'))
-        pypy_name = 'pypy' + '_nt' * (os.name == 'nt')
-        return pypy_name if old_pypy and prefix else name
+        _select_scheme(self, name)
 
     def _expand_attrs(self, attrs):
         for attr in attrs:
